FUNCTION KillApp
*==============================================================================
* Program:				KillApp.PRG
* Purpose:				Close any invisible instances of a specified program
* Author:				Tamar E. Granor
* Copyright:			(c) 2002 Tamar E. Granor
* Last revision:			04/16/02
* Parameters:			tcClassName - the classname of the app to close
* Returns:				Number of instances closed; -1, if parameter problems
* Environment in:		
* Environment out:		Several API functions declared
*==============================================================================
#DEFINE GW_CHILD 5
#DEFINE GW_HWNDNEXT 2
#DEFINE WM_CLOSE 0x10 

LPARAMETERS tcClassName

ASSERT VARTYPE(tcClassName) = "C" AND NOT EMPTY(tcClassName) ;
	MESSAGE "KillApp: Must pass class name of application to kill"
	
IF VARTYPE(tcClassName) <> "C" OR EMPTY(tcClassName)
	ERROR 11
	RETURN -1
ENDIF

DECLARE LONG GetDesktopWindow IN WIN32API 
DECLARE LONG GetWindow IN WIN32API LONG hWnd, LONG wCmd
DECLARE LONG IsWindowVisible IN WIN32API LONG hWnd
DECLARE LONG GetClassName IN WIN32API LONG hWnd, STRING lpClassName, LONG nMaxCount 
DECLARE LONG PostMessage IN WIN32API LONG hwnd, LONG wMsg, LONG wParam, LONG lParam 

LOCAL lnDesktopHWnd, lnHWnd, lnOldHWnd, lcClass, lnLen, nClosedCount

lnDesktopHWnd = GetDesktopWindow()
lnHWnd = GetWindow( lnDesktopHWnd, GW_CHILD)
lnClosedCount = 0

DO WHILE lnHWnd <> 0
	lcClass = SPACE(256)
	lnLen = GetClassName( lnHWnd, @lcClass, 256)
	lnOldHWnd = lnHWnd
	lnHWnd = GetWindow(lnOldHWnd, GW_HWNDNEXT)
	IF UPPER(LEFT(lcClass, lnLen)) = UPPER(tcClassName)
		lnVisible = IsWindowVisible(lnOldHWnd)
		IF lnVisible = 0
			PostMessage( lnOldHWnd, WM_CLOSE, 0, 0)
			lnClosedCount = lnClosedCount + 1 
		ENDIF 
	ENDIF 
ENDDO

RETURN lnClosedCount

FUNCTION KillWord
*==============================================================================
* Program:				KILLWord.PRG
* Purpose:				Close any invisible instances of Microsoft Word
* Author:				Tamar E. Granor
* Copyright:			(c) 2002 Tamar E. Granor
* Last revision:			05/10/2002
* Parameters:			(None)
* Returns:				Number of instances closed
* Environment in:		
* Environment out:		Several API functions declared
*==============================================================================
LOCAL lnKilled

lnKilled = KillApp("OpusApp")

RETURN lnKilled

FUNCTION KillExcel
*==============================================================================
* Program:				KILLExcel.PRG
* Purpose:				Close any invisible instances of Microsoft Excel
* Author:				Tamar E. Granor
* Copyright:			(c) 2002 Tamar E. Granor
* Last revision:			05/10/2002
* Parameters:			(None)
* Returns:				Number of instances closed
* Environment in:		
* Environment out:		Several API functions declared
*==============================================================================

LOCAL lnKilled

lnKilled = KillApp("XLMain")

RETURN lnKilled

FUNCTION KillPowerPoint
*==============================================================================
* Program:				KILLPowerPoint.PRG
* Purpose:				Close any invisible instances of Microsoft PowerPoint 2000
* Author:				Tamar E. Granor
* Copyright:			(c) 2002 Tamar E. Granor
* Last revision:			05/10/2002
* Parameters:			(None)
* Returns:				Number of instances closed
* Environment in:		
* Environment out:		Several API functions declared
*==============================================================================
LOCAL lnKilled

**********************************************************************
* Note: This routine works only with PowerPoint 2000.
* 		For PowerPoint 97, use "PP7FrameClass"
*		For PowerPoint XP, use "PP10FrameClass"
*		For PowerPoint 2003, use "PP11FrameClass"
**********************************************************************
lnKilled = KillApp("PP9FrameClass")

RETURN lnKilled

FUNCTION KillOfficeApps
*==============================================================================
* Program:				KILLOfficeApps.PRG
* Purpose:				Close any invisible instances of Microsoft Word, Excel, 
*						and PowerPoint 2000
* Author:				Tamar E. Granor
* Copyright:			(c) 2002 Tamar E. Granor
* Last revision:			05/10/2002
* Parameters:			(None)
* Returns:				Number of instances closed
* Environment in:		
* Environment out:		Several API functions declared
*==============================================================================
LOCAL lnTotalKilled, lnKilled, aAppsToKill[3], lnPos

aAppsToKill[1] = "OpusApp" && Word
aAppsToKill[2] = "XLMain"  && Excel
aAppsToKill[3] = "PP9FrameClass"  && PowerPoint 2000

lnTotalKilled = 0

FOR lnPos = 1 TO ALEN(aAppsToKill, 1)
	lnKilled = KillApp( aAppsToKill[lnPos])
	lnTotalKilled = lnTotalKilled + lnKilled
ENDFOR

RETURN lnTotalKilled
