*==============================================================================
* Class:				OfficeHandler
* Based On:				Session
* Purpose:				Implements Office server events
* Author:				Tamar E. Granor
* Copyright:			(c) 2004 Tamar E. Granor, Ph.D.
* Last revision:		4/19/2004
* Include file:			None
*==============================================================================
* Note: This version works only in VFP 9 and later. Due to a bug,
* VFP 8 can't implement the event interfaces for Excel and PowerPoint
* with a single class. For an equivalent (though much more complex) version
* of this class that works in VFP 8, see OfficeEventHandler.PRG
*******************************************************************************
DEFINE CLASS OfficeHandler AS session OLEPUBLIC

	* Word
    IMPLEMENTS applicationevents2 in {00020905-0000-0000-C000-000000000046}#8.1
    * Excel
    IMPLEMENTS AppEvents IN "Excel.Application"
    * PowerPoint
    IMPLEMENTS EApplication IN "PowerPoint.Application"


	PROTECTED cLogTable, cLogPath, cLogFullPath
	cLogTable = "OfficeLogEventHandler.DBF"
*  	colHandlers = .null.	&& collection of actual handlers

	PROCEDURE Init
	
	This.cLogPath = SYS(2023)
	This.cLogFullPath = FORCEPATH(This.cLogTable, ;
    	                          This.cLogPath)

	* Make sure the log table exists
	IF NOT FILE(This.cLogFullPath)
    	CREATE TABLE (This.cLogFullPath) ;
          (cDocument C(60), cAction C(12), tModified T)
        CLOSE TABLES 
	ENDIF
	
	SET EXCLUSIVE OFF 
	RETURN 

	*****
	* Begin Word events
	*****
	PROCEDURE ApplicationEvents2_DocumentOpen(Doc AS VARIANT) AS VOID

	* Log open
	INSERT INTO (This.cLogFullPath) ;
         VALUES (Doc.FullName, "Opened", DATETIME())

	RETURN .t.

	ENDPROC

	PROCEDURE ApplicationEvents2_DocumentBeforeClose(Doc AS VARIANT, Cancel AS LOGICAL) AS VOID

	* Log close
	INSERT INTO (This.cLogFullPath) ;
         VALUES (Doc.FullName, "Closed", DATETIME())

	RETURN .t.

	ENDPROC

	PROCEDURE ApplicationEvents2_DocumentBeforeSave(Doc AS VARIANT, SaveAsUI AS LOGICAL, Cancel AS LOGICAL) AS VOID

	* Log save
	INSERT INTO (This.cLogFullPath) ;
         VALUES (Doc.FullName, "Saved", DATETIME())

	RETURN .t.

	ENDPROC

	PROCEDURE ApplicationEvents2_NewDocument(Doc AS VARIANT) AS VOID

	* Log create
	INSERT INTO (This.cLogFullPath) ;
         VALUES (Doc.FullName, "Created", DATETIME())

	RETURN .t.

	ENDPROC

	*****
	* Not using these events of Word 
	*****
	PROCEDURE ApplicationEvents2_DocumentBeforePrint(Doc AS VARIANT, Cancel AS LOGICAL) AS VOID
		* add user code here
	ENDPROC

	PROCEDURE ApplicationEvents2_Quit() AS VOID
		* add user code here
	ENDPROC

	PROCEDURE ApplicationEvents2_DocumentChange() AS VOID
		* add user code here
	ENDPROC

	PROCEDURE ApplicationEvents2_WindowActivate(Doc AS VARIANT, Wn AS VARIANT) AS VOID
		* add user code here
	ENDPROC

	PROCEDURE ApplicationEvents2_WindowDeactivate(Doc AS VARIANT, Wn AS VARIANT) AS VOID
		* add user code here
	ENDPROC

	PROCEDURE ApplicationEvents2_WindowSelectionChange(Sel AS VARIANT) AS VOID
		* add user code here
	ENDPROC

	PROCEDURE ApplicationEvents2_WindowBeforeRightClick(Sel AS VARIANT, Cancel AS LOGICAL) AS VOID
		* add user code here
	ENDPROC

	PROCEDURE ApplicationEvents2_WindowBeforeDoubleClick(Sel AS VARIANT, Cancel AS LOGICAL) AS VOID
		* add user code here
	ENDPROC
	

	*****
	* Begin Excel events
	*****

	PROCEDURE AppEvents_NewWorkbook(Wb AS VARIANT) AS VOID

	* Log create
	INSERT INTO (This.cLogFullPath) ;
         VALUES (Wb.FullName, "Created", DATETIME())

	RETURN .t.

	ENDPROC

	PROCEDURE AppEvents_WorkbookOpen(Wb AS VARIANT) AS VOID

	* Log open
	INSERT INTO (This.cLogFullPath) ;
         VALUES (Wb.FullName, "Opened", DATETIME())

	RETURN .t.

	ENDPROC

	PROCEDURE AppEvents_WorkbookBeforeClose(Wb AS VARIANT, Cancel AS LOGICAL) AS VOID

	* Log close
	INSERT INTO (This.cLogFullPath) ;
         VALUES (Wb.FullName, "Closed", DATETIME())

	RETURN .t.

	ENDPROC

	PROCEDURE AppEvents_WorkbookBeforeSave(Wb AS VARIANT, SaveAsUI AS LOGICAL, Cancel AS LOGICAL) AS VOID

	* Log save
	INSERT INTO (This.cLogFullPath) ;
         VALUES (Wb.FullName, "Saved", DATETIME())

	RETURN .t.

	ENDPROC

	*****
	* Not using these events of Excel
	*****
	PROCEDURE AppEvents_WorkbookActivate(Wb AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_WorkbookDeactivate(Wb AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_SheetSelectionChange(Sh AS VARIANT, Target AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_SheetBeforeDoubleClick(Sh AS VARIANT, Target AS VARIANT, Cancel AS LOGICAL) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_SheetBeforeRightClick(Sh AS VARIANT, Target AS VARIANT, Cancel AS LOGICAL) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_SheetActivate(Sh AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_SheetDeactivate(Sh AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_SheetCalculate(Sh AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_SheetChange(Sh AS VARIANT, Target AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_WorkbookBeforePrint(Wb AS VARIANT, Cancel AS LOGICAL) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_WorkbookNewSheet(Wb AS VARIANT, Sh AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_WorkbookAddinInstall(Wb AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_WorkbookAddinUninstall(Wb AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_WindowResize(Wb AS VARIANT, Wn AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_WindowActivate(Wb AS VARIANT, Wn AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_WindowDeactivate(Wb AS VARIANT, Wn AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_SheetFollowHyperlink(Sh AS VARIANT, Target AS VARIANT) AS VOID
	* add user code here
	ENDPROC
	
	* Excel 2002 and later
	PROCEDURE AppEvents_SheetPivotTableUpdate(Sh AS VARIANT, Target AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_WorkbookPivotTableCloseConnection(Wb AS VARIANT, Target AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE AppEvents_WorkbookPivotTableOpenConnection(Wb AS VARIANT, Target AS VARIANT) AS VOID
	* add user code here
	ENDPROC




	*****
	* Begin PowerPoint events
	*****
	PROCEDURE EApplication_PresentationClose(Pres AS VARIANT) AS VOID
	* Log close 
	INSERT INTO (This.cLogFullPath) ;
         VALUES (Pres.FullName, "Closed", DATETIME())

	RETURN .t.
	ENDPROC

	PROCEDURE EApplication_PresentationSave(Pres AS VARIANT) AS VOID
	* Log save 
	INSERT INTO (This.cLogFullPath) ;
         VALUES (Pres.FullName, "Saved", DATETIME())

	RETURN .t.
	ENDPROC

	PROCEDURE EApplication_PresentationOpen(Pres AS VARIANT) AS VOID
	* Log open
	INSERT INTO (This.cLogFullPath) ;
         VALUES (Pres.FullName, "Opened", DATETIME())

	RETURN .t.
	ENDPROC

	PROCEDURE EApplication_NewPresentation(Pres AS VARIANT) AS VOID
	* Log creation
	INSERT INTO (This.cLogFullPath) ;
         VALUES (Pres.FullName, "Created", DATETIME())

	RETURN .t.
	ENDPROC

	*****
	* Not using these events of PowerPoint
	*****
	PROCEDURE EApplication_WindowSelectionChange(Sel AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_WindowBeforeRightClick(Sel AS VARIANT, Cancel AS LOGICAL @) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_WindowBeforeDoubleClick(Sel AS VARIANT, Cancel AS LOGICAL @) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_PresentationNewSlide(Sld AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_WindowActivate(Pres AS VARIANT, Wn AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_WindowDeactivate(Pres AS VARIANT, Wn AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_SlideShowBegin(Wn AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_SlideShowNextBuild(Wn AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_SlideShowNextSlide(Wn AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_SlideShowEnd(Pres AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_PresentationPrint(Pres AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	* PowerPoint 2002 and later
	PROCEDURE EApplication_SlideSelectionChanged(SldRange AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_ColorSchemeChanged(SldRange AS VARIANT) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_PresentationBeforeSave(Pres AS VARIANT, Cancel AS LOGICAL @) AS VOID
	* add user code here
	ENDPROC

	PROCEDURE EApplication_SlideShowNextClick(Wn AS VARIANT, nEffect AS VARIANT) AS VOID
	* add user code here
	ENDPROC
	
ENDDEFINE

