*==============================================================================
* Class:					OfficeResponder
* Based On:					Session
* Purpose:					COM object called by Office add-ins
* Author:					Tamar E. Granor
* Copyright:				(c) 2003 Tamar E. Granor, Ph.D.
* Last revision:			3/28/2003
* Include file:				None
*==============================================================================
DEFINE CLASS OfficeResponder AS Session OLEPUBLIC
* COM server to be called in response to Office events.

PROTECTED cLogTable, cLogPath, cLogFullPath
cLogTable = "OfficeLogFromAddIn.DBF"

PROTECTED PROCEDURE Init
* Set up

This.cLogPath = SYS(2023)
This.cLogFullPath = FORCEPATH(This.cLogTable, ;
                              This.cLogPath)

* Make sure the log table exists
IF NOT FILE(This.cLogFullPath)
    CREATE TABLE (This.cLogFullPath) ;
        (cDocument C(60), cAction C(12), tModified T)
    CLOSE TABLES 
ENDIF

SET EXCLUSIVE OFF 
RETURN 

ENDPROC

PROCEDURE UpdateLog( cDocument as String, cAction as String) as Boolean
* Update the activity log

IF VARTYPE(cDocument) <> "C" OR EMPTY(cDocument)
    ERROR 11
    RETURN .F.
ENDIF

IF VARTYPE(cAction) <> "C" OR EMPTY(cAction)
	ERROR 11
	RETURN .f.
ENDIF 

INSERT INTO (This.cLogFullPath) ;
   VALUES (m.cDocument, m.cAction, DATETIME())

RETURN .t.

ENDPROC 

PROCEDURE Error(nError, cMethod, nLine)

LOCAL lcErrorMsg, lcFileName

lcErrorMsg = "Error " + TRANSFORM(nError) + SPACE(1) + ;
             CHR(13) + CHR(10) + ;
             "Method " + cMethod + SPACE(1) + ;
             CHR(13) + CHR(10) + ;
             "Line " + TRANSFORM(nLine) + SPACE(1) + ;
             CHR(13) + CHR(10)+ ;
             "At " + TRANSFORM(DATETIME())

************************************************
* Dump an error log into the specified directory
************************************************
lcFileName = FORCEPATH("OfficeResponder.ERR", ;
                       This.cLogPath)
STRTOFILE(lcErrorMsg, lcFileName, .T.)
LIST MEMORY TO FILE (lcFileName) ADDITIVE noconsole
LIST STATUS TO FILE (lcFileName)  ADDITIVE noconsole
RETURN   
ENDPROC

ENDDEFINE
